# ktch - A python package for model-based morphometrics

[![PyPI version](https://badge.fury.io/py/ktch.svg)](https://pypi.org/project/ktch/) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/ktch/badges/version.svg)](https://anaconda.org/conda-forge/ktch) [![codecov](https://codecov.io/gh/noshita/ktch/branch/main/graph/badge.svg?token=SJN66K7KJY)](https://codecov.io/gh/noshita/ktch)

ktch is a python package for model-based morphometrics.

## Usage

```sh
# pip
pip install ktch

# conda
conda install -c conda-forge ktch 
```


## License

ktch is licensed under the Apache License, Version2.0
